@@ -2,13 +2,13 @@
 # -*- coding: utf-8 -*-
 
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
-# <quodlibet@lists.sacredchao.net>
+# <quod-libet-development@googlegroups.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 #
-# $Id: quodlibet.py 3835 2006-09-10 21:08:27Z piman $
+# $Id: quodlibet.py 4330 2008-09-14 03:19:26Z piman $
 
 import os
 import signal
@@ -16,41 +16,53 @@ import sys
 import tempfile
 import time
 
-import config
-import const
-import util
+import quodlibet, quodlibet.player
+
+from quodlibet import config
+from quodlibet import const
+from quodlibet import util
 
 from threading import Thread
 
-from util import to
-
 global play
 play = False
 
 def main():
-    # Load configuration data and scan the library for new/changed songs.
     config.init(const.CONFIG)
-    library = load_library()
-    player = load_player(library)
 
-    import widgets
+    try:
+        backend, library, player = quodlibet.init(
+            backend=config.get("player", "backend"),
+            library=const.LIBRARY,
+            )
+    except quodlibet.player.error, error:
+        import gobject
+        import gtk
+        gobject.idle_add(quodlibet.error_and_quit, error)
+        gobject.idle_add(gtk.main_quit)
+        gtk.main()
+        config.write(const.CONFIG)
+        raise SystemExit(True)
 
-    util.mkdir(const.USERDIR)
-    SIGNALS = [signal.SIGINT, signal.SIGTERM, signal.SIGHUP]
+    from quodlibet import widgets
 
     try: ratings = config.getint("settings", "ratings")
     except (ValueError, TypeError): pass
     else: util.RATING_PRECISION = 1.0/ratings
 
+    try: default_rating = config.getfloat("settings", "default_rating")
+    except (ValueError, TypeError): pass
+    else: const.DEFAULT_RATING = default_rating
+
     window = widgets.init(player, library)
     if "--debug" not in sys.argv:
         enable_periodic_save(library)
-        gtk.quit_add(1, widgets.save_library, window, player, library)
-    for sig in SIGNALS:
-        signal.signal(sig, gtk.main_quit)
-    gtk.gdk.threads_init()
-    if play: player.paused = False
-    gtk.main()
+    if play:
+        player.paused = False
+    quodlibet.main(window)
+    quodlibet.quit((backend, library, player), save=True)
+    try: config.write(const.CONFIG)
+    except EnvironmentError, err: pass
 
 def print_fifo(command):
     if not os.path.exists(const.CURRENT):
@@ -81,8 +93,8 @@ def print_fifo(command):
             raise SystemExit("not-running")
 
 def print_playing(fstring="<artist~album~tracknumber~title>"):
-    from formats._audio import AudioFile
-    from parse import Pattern
+    from quodlibet.formats._audio import AudioFile
+    from quodlibet.parse import Pattern
 
     try:
         fn = file(const.CURRENT)
@@ -99,10 +111,10 @@ def print_playing(fstring="<artist~album~tracknumber~title>"):
                 if key != "~filename": val = util.decode(val)
                 if key in data: data[key] += "\n" + val
                 else: data[key] = val
-        print to(Pattern(fstring).format(AudioFile(data)))
+        print_(Pattern(fstring).format(AudioFile(data)))
         raise SystemExit
     except (OSError, IOError):
-        print to(_("No song is currently playing."))
+        print_(_("No song is currently playing."))
         raise SystemExit(True)
 
 def isrunning():
@@ -110,7 +122,7 @@ def isrunning():
 
 def control(c):
     if not isrunning():
-        raise SystemExit(to(_("Quod Libet is not running.")))
+        raise SystemExit(_("Quod Libet is not running."))
     else:
         try:
             # This is a total abuse of Python! Hooray!
@@ -121,7 +133,7 @@ def control(c):
             f.write(c)
             f.close()
         except (OSError, IOError, TypeError):
-            print to(_("Unable to write to %s. Removing it.") % const.CONTROL)
+            print_w(_("Unable to write to %s. Removing it.") % const.CONTROL)
             try: os.unlink(const.CONTROL)
             except OSError: pass
             if c != 'focus':
@@ -136,10 +148,11 @@ def enable_periodic_save(library):
     import gobject
 
     def save():
-        if (time.time() - util.mtime(const.LIBRARY)) > 15*60:
-            library.save(const.LIBRARY)
-        if (time.time() - util.mtime(const.CONFIG)) > 15*60:
-            config.write(const.CONFIG)
+        if library.dirty:
+            if (time.time() - util.mtime(const.LIBRARY)) > 15*60:
+                library.save(const.LIBRARY)
+            if (time.time() - util.mtime(const.CONFIG)) > 15*60:
+                config.write(const.CONFIG)
         thread = Thread(target=save)
         gobject.timeout_add(
             5*60000, thread.start, priority=gobject.PRIORITY_LOW)
@@ -149,10 +162,10 @@ def enable_periodic_save(library):
 def process_arguments():
     controls = ["next", "previous", "play", "pause", "play-pause",
                 "hide-window", "show-window", "toggle-window",
-                "focus", "quit"]
+                "focus", "quit", "unfilter", "refresh"]
     controls_opt = ["seek", "order", "repeat", "query", "volume", "filter",
                     "set-rating", "set-browser", "open-browser", "random",
-                    "song-list", "queue", "enqueue"]
+                    "song-list", "queue", "enqueue", "unqueue"]
 
     options = util.OptionParser(
         "Quod Libet", const.VERSION, 
@@ -175,6 +188,8 @@ def process_arguments():
         ("show-window", _("Show main window")),
         ("toggle-window", _("Toggle main window visibility")),
         ("focus", _("Focus the running player")),
+        ("unfilter", _("Remove active browser filters")),
+        ("refresh", _("Refresh and rescan library")),
         ("print-playlist", _("Print the current playlist")),
         ("print-queue", _("Print the contents of the queue")),
         ("quit", _("Exit Quod Libet")),
@@ -197,6 +212,8 @@ def process_arguments():
         ("filter", _("Filter on a tag value"), _("tag=value")),
         ("enqueue", _("Enqueue a file or query"), "%s|%s" %(
         Q_("command|filename"), _("query"))),
+        ("unqueue", _("Unqueue a file or query"), "%s|%s" %(
+        Q_("command|filename"), _("query"))),
         ]: options.add(opt, help=help, arg=arg)
 
     options.add("sm-config-prefix", arg="dummy")
@@ -229,10 +246,9 @@ def process_arguments():
         if command in controls: control(command)
         elif command in controls_opt:
             if command in validators and not validators[command](arg):
-                sys.stderr.write(
-                    to(_("E: Invalid argument for '%s'.") % command))
-                sys.stderr.write("\n")
-                raise SystemExit(to(_("E: Try %s --help.") % sys.argv[0]))
+                print_e(_("Invalid argument for '%s'.") % command)
+                print_e(_("Try %s --help.") % sys.argv[0])
+                raise SystemExit(True)
             else: control(command + " " + arg)
         elif command == "status": print_fifo("status")
         elif command == "print-playlist": print_fifo("dump-playlist")
@@ -250,52 +266,9 @@ def process_arguments():
             global play
             play = True
 
-def load_library():
-    import library
-    lib = library.init(const.LIBRARY)
-    print to(_("Loaded song library."))
-    return lib
-
-def load_player(library):
-    # Try to initialize the playlist and audio output.
-    print to(_("Opening audio device."))
-    import player
-    sink = config.get("settings", "pipeline")
-    try: playlist = player.init(sink, library.librarian)
-    except player.NoSinkError:
-        import widgets, gobject
-        gobject.idle_add(widgets.no_sink_quit, sink)
-        gtk.main()
-        config.write(const.CONFIG)
-        raise SystemExit(True)
-    except player.NoSourceError:
-        import widgets, gobject
-        gobject.idle_add(widgets.no_source_quit)
-        gtk.main()
-        config.write(const.CONFIG)
-        raise SystemExit(True)
-    else: return playlist
-
 if __name__ == "__main__":
-    basedir = os.path.dirname(os.path.realpath(__file__))
-    if basedir.endswith("/share/quodlibet"):
-        sys.path.append(basedir[:-15] + "lib/quodlibet")
-
-    util.python_init()
-    util.gettext_install()
-    util.ctypes_init()
-
-    if "--debug" not in sys.argv:
-        process_arguments()
-        if isrunning():
-            print to(_("Quod Libet is already running."))
-            control('focus')
-
-    # GTK+ eats command line arguments and babies, so we have to delay
-    # imports until at least this late.
-    util.gtk_init()
-    import gtk
-    import pygst
-    pygst.require('0.10')
-
+    process_arguments()
+    if isrunning() and not os.environ.get("QUODLIBET_DEBUG"):
+        print_(_("Quod Libet is already running."))
+        control('focus')
     main()
