@@ -1,31 +1,33 @@
-import gobject, gtk
 from tests import TestCase, add
 
-import widgets
-import browsers.search
-from browsers.search import EmptyBar, SearchBar
-from formats._audio import AudioFile as AF
-from qltk.watcher import SongWatcher
+import gtk
 
-import __builtin__
-__builtin__.__dict__['_'] = lambda a: a
+from quodlibet import widgets
+import quodlibet.browsers.search
+import quodlibet.config
 
-from library import Library
+from quodlibet.browsers.search import EmptyBar, SearchBar
+from quodlibet.formats._audio import AudioFile
+from quodlibet.library import SongLibrary
 
-SONGS = [AF({"title": "one", "artist": "piman", "~filename": "/dev/null"}),
-         AF({"title": "two", "artist": "mu", "~filename": "/dev/zero"}),
-         AF({"title": "three", "artist": "boris", "~filename": "/bin/ls"})
+SONGS = [AudioFile(
+    {"title": "one", "artist": "piman", "~filename": "/dev/null"}),
+         AudioFile(
+    {"title": "two", "artist": "mu", "~filename": "/dev/zero"}),
+         AudioFile(
+    {"title": "three", "artist": "boris", "~filename": "/bin/ls"})
          ]
 SONGS.sort()
 
 class TEmptyBar(TestCase):
     Bar = EmptyBar
     def setUp(self):
-        browsers.search.library = Library()
+        quodlibet.config.init()
+        quodlibet.browsers.search.library = SongLibrary()
         for af in SONGS:
             af.sanitize()
-            browsers.search.library.add_song(af)
-        self.bar = self.Bar(SongWatcher(), False)
+        quodlibet.browsers.search.library.add(SONGS)
+        self.bar = self.Bar(quodlibet.browsers.search.library, False)
         self.bar.connect('songs-selected', self._expected)
 
     def _expected(self, bar, songs, sort):
@@ -54,6 +56,8 @@ class TEmptyBar(TestCase):
     def test_dynamic(self):
         self.failUnless(self.bar.dynamic(SONGS[0]))
         self.bar.set_text("this does not match any song")
+        self.expected = []
+        self.bar.activate()
         self.failIf(self.bar.dynamic(SONGS[0]))
 
     def test_filter(self):
@@ -86,20 +90,10 @@ class TEmptyBar(TestCase):
 
     def tearDown(self):
         self.bar.destroy()
-        browsers.search.library = Library()
+        quodlibet.browsers.search.library.destroy()
+        quodlibet.config.quit()
 add(TEmptyBar)
 
 class TSearchBar(TEmptyBar):
     Bar = SearchBar
-    def setUp(self):
-        import qltk
-        widgets.watcher = SongWatcher()
-        super(TSearchBar, self).setUp()
-
-    def test_ctr(self): pass
-
-    def tearDown(self):
-        super(TSearchBar, self).tearDown()
-        widgets.watcher.destroy()
-        del(widgets.watcher)
 add(TSearchBar)
