@@ -1,10 +1,10 @@
-import os, config
-
 from tests import TestCase, add
-from formats._audio import AudioFile
 
-try: from sets import Set as set
-except ImportError: pass
+import os
+
+from quodlibet import config
+
+from quodlibet.formats._audio import AudioFile
 
 bar_1_1 = AudioFile({
     "title": "A song",
@@ -157,12 +157,10 @@ class TAudioFile(TestCase):
         quux.rename(dir + old_fn)
         self.failUnless(quux.exists())
 
-        # rename to existing files
+    def test_rename_to_existing(self):
         quux.rename(quux("~basename"))
-        self.failUnlessRaises(ValueError,
-                              lambda: quux.rename("/dev/null"))
-        self.failUnlessRaises(ValueError,
-                              lambda: quux.rename("silence-44-s.ogg"))
+        self.failUnlessRaises(ValueError, quux.rename, "/dev/null")
+        self.failUnlessRaises(ValueError, quux.rename, "silence-44-s.ogg")
 
     def test_website(self):
         song = AudioFile()
@@ -186,6 +184,16 @@ class TAudioFile(TestCase):
         q.sanitize()
         self.failUnlessRaises(ValueError, b.sanitize)
 
+    def test_performers(self):
+        q = AudioFile([("performer:vocals", "A"), ("performer:guitar", "B"),
+                       ("performer", "C")])
+        self.failUnless("A (vocals)" in q.list("~performers"))
+        self.failUnless("B (guitar)" in q.list("~performers"))
+        self.failUnless("C" in q.list("~performers"))
+        self.failUnless("A (vocals)" in q.list("~people"))
+        self.failUnless("B (guitar)" in q.list("~people"))
+        self.failUnlessEqual(len(q.list("~performers")), 3)
+
     def test_to_dump(self):
         dump = bar_1_1.to_dump()
         self.failUnlessEqual(dump.count("\n"), len(bar_1_1) + 1)
@@ -235,6 +243,63 @@ class TAudioFile(TestCase):
         song.change("foo", "finally", "we're done")
         self.failUnlessEqual(song["foo"], "we're done")
 
+    def test_bookmarks_none(self):
+        self.failUnlessEqual([], AudioFile().bookmarks)
+
+    def test_bookmarks_simple(self):
+        af = AudioFile({"~bookmark": "1:20 Mark 1"})
+        self.failUnlessEqual([(80, "Mark 1")], af.bookmarks)
+
+    def test_bookmarks_two(self):
+        af = AudioFile({"~bookmark": "1:40 Mark 2\n1:20 Mark 1"})
+        self.failUnlessEqual([(80, "Mark 1"), (100, "Mark 2")], af.bookmarks)
+
+    def test_bookmark_invalid(self):
+        af = AudioFile({"~bookmark": ("Not Valid\n1:40 Mark 2\n"
+                                      "-20 Not Valid 2\n1:20 Mark 1")})
+        self.failUnlessEqual(
+            [(80, "Mark 1"), (100, "Mark 2"), (-1, "Not Valid"),
+             (-1, "-20 Not Valid 2")], af.bookmarks)
+
+    def test_set_bookmarks_none(self):
+        af = AudioFile({"bookmark": "foo"})
+        af.bookmarks = []
+        self.failUnlessEqual([], AudioFile().bookmarks)
+        self.failIf("~bookmark" in af)
+
+    def test_set_bookmarks_simple(self):
+        af = AudioFile()
+        af.bookmarks = [(120, "A mark"), (140, "Mark twain")]
+        self.failUnlessEqual(af["~bookmark"], "2:00 A mark\n2:20 Mark twain")
+
+    def test_set_bookmarks_invalid_value(self):
+        self.failUnlessRaises(
+            ValueError, setattr, AudioFile(), 'bookmarks', "huh?")
+    def test_set_bookmarks_invalid_time(self):
+        self.failUnlessRaises(
+            TypeError, setattr, AudioFile(), 'bookmarks', [("notint", "!")])
+    def test_set_bookmarks_unrealistic_time(self):
+        self.failUnlessRaises(
+            ValueError, setattr, AudioFile(), 'bookmarks', [(-1, "!")])
+
+    def test_album_key(self):
+        self.failUnlessEqual(AudioFile().album_key, ("", ""))
+
+        album = AudioFile(album="foo")
+        self.failUnlessEqual(album.album_key, ("foo", ""))
+
+        labelid = AudioFile(labelid="foo")
+        self.failUnlessEqual(labelid.album_key, ("", "foo"))
+
+        mbid = AudioFile(musicbrainz_albumid="foo")
+        self.failUnlessEqual(mbid.album_key, ("", "foo"))
+
+        title_id = AudioFile(album="foo", labelid="bar")
+        self.failUnlessEqual(title_id.album_key, ("foo", "bar"))
+
+        all = AudioFile(album="foo", labelid="bar", musicbrainz_albumid="quux")
+        self.failUnlessEqual(all.album_key, ("foo", "bar"))
+
     def tearDown(self):
         os.unlink(quux["~filename"])
 add(TAudioFile)
@@ -247,29 +312,25 @@ class Treplay_gain(TestCase):
                                "replaygain_track_peak": "0.9"})
 
     def test_nogain(self):
-        config.set("settings", "gain", 0)
-        self.failUnlessEqual(self.song.replay_gain(), 1)
+        self.failUnlessEqual(self.song.replay_gain(["none", "track"]), 1)
 
     def test_trackgain(self):
-        config.set("settings", "gain", 1)
-        self.failUnless(self.song.replay_gain() > 1)
+        self.failUnless(self.song.replay_gain(["track"]) > 1)
 
     def test_albumgain(self):
-        config.set("settings", "gain", 2)
-        self.failUnless(self.song.replay_gain() < 1)
+        self.failUnless(self.song.replay_gain(["album"]) < 1)
 
     def test_invalid(self):
         self.song["replaygain_album_gain"] = "fdsodgbdf"
-        self.failUnlessEqual(self.song.replay_gain(), 1)
+        self.failUnlessEqual(self.song.replay_gain(["album"]), 1)
 
     def test_track_fallback(self):
-        config.set("settings", "gain", 1)
-        radio_rg = self.song.replay_gain()
-        config.set("settings", "gain", 2)
+        radio_rg = self.song.replay_gain(["track"])
         del(self.song["replaygain_album_gain"])
         del(self.song["replaygain_album_peak"])
         # verify defaulting to track when album is present
-        self.failUnlessAlmostEqual(self.song.replay_gain(), radio_rg)
+        self.failUnlessAlmostEqual(
+            self.song.replay_gain(["album", "track"]), radio_rg)
 add(Treplay_gain)
 
 # Special test case for find_cover since it has to create/remove
