@@ -1,5 +1,7 @@
-from tests import add, TestCase
-from qltk.renamefiles import SpacesToUnderscores, StripWindowsIncompat, StripDiacriticals, StripNonASCII
+from tests import TestCase, add
+
+from quodlibet.qltk.renamefiles import SpacesToUnderscores, StripWindowsIncompat
+from quodlibet.qltk.renamefiles import StripDiacriticals, StripNonASCII
 
 class TFilter(TestCase):
     def setUp(self): self.c = self.Kind()
@@ -21,6 +23,10 @@ class TStripWindowsIncompat(TFilter):
     Kind = StripWindowsIncompat
     def test_conv(self):
         self.failUnlessEqual(self.c.filter("", 'foo\\:*?;"<>|'), "foo_________")
+
+    def test_ends_with_dots_or_spaces(self):
+        self.failUnlessEqual(self.c.filter("", 'foo. . '), "foo. ._")
+        self.failUnlessEqual(self.c.filter("", 'foo. /bar .'), "foo._/bar _")
 add(TStripWindowsIncompat)
 
 class TStripDiacriticals(TFilter):
