@@ -1,5 +1,6 @@
 from tests import TestCase, add
-from qltk.textedit import TextEditBox, TextEdit
+
+from quodlibet.qltk.textedit import TextEditBox, TextEdit
 
 class TTextEditBox(TestCase):
     def setUp(self):
