@@ -1,6 +1,7 @@
-import gtk
 from tests import TestCase, add
-from qltk import x
+
+import gtk
+from quodlibet.qltk import x
 
 class Window(TestCase):
     def test_ctr(self):
